@@ -13,8 +13,9 @@ let () =
       let audio_idx, audio_src, _ = Av.find_best_audio_stream src in
 
       let audio_dst = Avdevice.open_default_audio_output () in
+      let _, audio_stream, _ = List.hd (Av.get_audio_streams audio_dst) in
 
-      (Some (audio_idx, audio_dst), [audio_src])
+      (Some (audio_idx, audio_dst, audio_stream), [audio_src])
     with Avutil.Error _ -> (None, [])
   in
 
@@ -23,18 +24,19 @@ let () =
       let video_idx, video_src, _ = Av.find_best_video_stream src in
 
       let video_dst = Avdevice.open_video_output "xv" in
+      let _, video_stream, _ = List.hd (Av.get_video_streams video_dst) in
 
-      (Some (video_idx, video_dst), [video_src])
+      (Some (video_idx, video_dst, video_stream), [video_src])
     with Avutil.Error _ -> (None, [])
   in
 
   let rec f () =
     match (Av.read_input ~audio_frame ~video_frame src, audio, video) with
-      | `Audio_frame (i, frame), Some (idx, dst), _ when i = idx ->
-          Av.write_audio_frame dst frame;
+      | `Audio_frame (i, frame), Some (idx, _, stream), _ when i = idx ->
+          Av.write_frame stream frame;
           f ()
-      | `Video_frame (i, frame), _, Some (idx, dst) when i = idx ->
-          Av.write_video_frame dst frame;
+      | `Video_frame (i, frame), _, Some (idx, _, stream) when i = idx ->
+          Av.write_frame stream frame;
           f ()
       | exception Avutil.Error `Eof -> ()
       | _ -> f ()
@@ -43,9 +45,9 @@ let () =
 
   Av.close src;
 
-  let () = match audio with Some (_, dst) -> Av.close dst | None -> () in
+  let () = match audio with Some (_, dst, _) -> Av.close dst | None -> () in
 
-  let () = match video with Some (_, dst) -> Av.close dst | None -> () in
+  let () = match video with Some (_, dst, _) -> Av.close dst | None -> () in
 
   Gc.full_major ();
   Gc.full_major ()
